"use strict";

var isImplemented = require("../../../array/of/is-implemented");

module.exports = function (a) { a(isImplemented(), true); };
